@@ -1,12 +1,13 @@
 import json
 import subprocess
+import os
 
 import requests
 from framl.config_cli import ConfigFraml
 
 
 class FeatureStore:
-    HOST = "https://feature-store-api-rzhg37iauq-ez.a.run.app"
+    HOST = os.getenv('FEATURE_STORE_HOST') or "https://feature-store-api-rzhg37iauq-ez.a.run.app"
 
     @staticmethod
     def _get_bearer() -> str:
